@@ -25,14 +25,14 @@
 #'  data(shortMove)
 #'
 #'  # test function for 5, 10 20 and 30 m
-#'  a.res <- sMoveRes(xy=shortMove, pixel.res=c(5, 10, 20, 30))
+#'  a.res <- sMoveRes(shortMove, c(5, 10, 20, 30))
 #'
 #' }
 #' @export
 
 #-------------------------------------------------------------------------------------------------------------------------------#
 
-sMoveRes <- function(xy=xy, pixel.res=pixel.res) {
+sMoveRes <- function(xy, pixel.res) {
 
 #---------------------------------------------------------------------------------------------------------------------#
 #  1. check inpur variables
